@@ -2,6 +2,7 @@
 # -*- coding: utf-8 -*-
 
 from __future__ import unicode_literals
+import json
 from django.forms import widgets, Media
 from django.template import Context
 from django.template.loader import get_template_from_string
@@ -13,7 +14,8 @@ __all__ = ['GhostdownInput', 'GHOSTDOWN_INPUT_TEMPLATE_STRING']
 
 
 class GhostdownInput(widgets.HiddenInput):
-    def __init__(self, attrs=None, live_preview=None, value_path=''):
+    def __init__(self, attrs=None, live_preview=None, value_path='',
+                 codemirror_options=None):
         super(GhostdownInput, self).__init__(attrs)
         if live_preview is None:
             self.live_preview = settings.GHOSTDOWN_USE_LIVE_PREVIEW
@@ -21,6 +23,9 @@ class GhostdownInput(widgets.HiddenInput):
             self.live_preview = live_preview
         if value_path:
             self.value_path = value_path
+        if codemirror_options is None:
+            codemirror_options = settings.GHOSTDOWN_CODEMIRROR_DEFAULT_OPTIONS
+        self.codemirror_options = codemirror_options
 
     def get_template(self):
         return get_template_from_string(GHOSTDOWN_INPUT_TEMPLATE_STRING)
@@ -42,6 +47,7 @@ class GhostdownInput(widgets.HiddenInput):
             'ghostdown_id': ghostdown_id,
             'content': value or '',
             'live_preview': self.live_preview,
+            'codemirror_options': json.dumps(self.codemirror_options),
         })
         return self.get_template().render(context)
 
